@@ -3,7 +3,7 @@ package Params::ValidationCompiler::Compiler;
 use strict;
 use warnings;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 use Carp qw( croak );
 use Eval::Closure qw( eval_closure );
@@ -358,7 +358,7 @@ sub _compile_positional_args_check {
 
     my $first_optional_idx = -1;
     for my $i ( 0 .. $#specs ) {
-        next unless $specs[$i]{optional};
+        next unless $specs[$i]{optional} || exists $specs[$i]{default};
         $first_optional_idx = $i;
         last;
     }
@@ -811,7 +811,7 @@ Params::ValidationCompiler::Compiler - Object that implements the check subrouti
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =for Pod::Coverage .*
 
